@@ -51,6 +51,7 @@ arma::sp_mat subcol_sp_mat(const arma::sp_mat& X, arma::uvec index);
 //' @param indexT A list containing, for each strata, which rows of the endpoint and status matrices corresponds to the treatment observations. Not unique when bootstraping.
 //' @param posT A list containing, for each strata, the unique identifier of each treatment observations.
 //' @param threshold Store the thresholds associated to each endpoint. Must have length D. The threshold is ignored for binary endpoints. 
+//' @param restriction Store the restriction time associated to each endpoint. Must have length D. 
 //' @param weight Store the weight associated to each endpoint. Must have length D. 
 //' @param method The index of the method used to score the pairs. Must have length D. 1 for binary/continuous, 2 for Gaussian, 3/4 for Gehan (left or right-censoring), and 5/6 for Peron (right-censoring survival or competing risks).
 //' @param op The index of the operator used to score the pairs. Must have length D. 1 for larger is beter, -1 for smaller is better.
@@ -100,6 +101,7 @@ Rcpp::List GPC_cpp(arma::mat endpoint,
 		   std::vector< arma::uvec > indexT,
 		   std::vector< arma::uvec > posT,
 		   std::vector< double > threshold,
+		   std::vector< double > restriction,
 		   arma::vec weight,
 		   arma::vec method,
 		   std::vector< int > op,
@@ -262,7 +264,7 @@ Rcpp::List GPC_cpp(arma::mat endpoint,
       arma::uvec iUvec_endpoint = {index_endpoint[iter_d]};
       arma::uvec iUvec_status = {index_status[iter_d]};
 
-      iPairScore = calcAllPairs(endpoint.submat(indexC[iter_strata],iUvec_endpoint), endpoint.submat(indexT[iter_strata],iUvec_endpoint), threshold[iter_d],
+      iPairScore = calcAllPairs(endpoint.submat(indexC[iter_strata],iUvec_endpoint), endpoint.submat(indexT[iter_strata],iUvec_endpoint), threshold[iter_d], restriction[iter_d],
 				status.submat(indexC[iter_strata],iUvec_status), status.submat(indexT[iter_strata],iUvec_status),
 				list_survTimeC[iter_d][iter_strata], list_survTimeT[iter_d][iter_strata], list_survJumpC[iter_d][iter_strata], list_survJumpT[iter_d][iter_strata],
 				list_lastSurv[iter_d].row(iter_strata),
@@ -290,7 +292,7 @@ Rcpp::List GPC_cpp(arma::mat endpoint,
 	arma::mat iDscore_Dnuisance_C_M1,iDscore_Dnuisance_T_M1;
 
 	// note the values in endpoint, status, survTime, survJump, lastSurv are not used (only their dimensions)
-	arma::mat iPairScore_M1 = calcAllPairs(endpoint.submat(indexC[iter_strata],iUvec_endpoint), endpoint.submat(indexT[iter_strata],iUvec_endpoint), threshold[iter_d],
+	arma::mat iPairScore_M1 = calcAllPairs(endpoint.submat(indexC[iter_strata],iUvec_endpoint), endpoint.submat(indexT[iter_strata],iUvec_endpoint), threshold[iter_d], restriction[iter_d],
 					       status.submat(indexC[iter_strata],iUvec_status), status.submat(indexT[iter_strata],iUvec_status),
 					       list_survTimeC[iter_d][iter_strata], list_survTimeT[iter_d][iter_strata], list_survJumpC[iter_d][iter_strata], list_survJumpT[iter_d][iter_strata],
 					       list_lastSurv[iter_d].row(iter_strata), 
@@ -447,6 +449,7 @@ Rcpp::List GPC2_cpp(arma::mat endpoint,
 		    std::vector< arma::uvec > indexT,
 		    std::vector< arma::uvec > posT,
 		    std::vector< double > threshold,
+		    std::vector< double > restriction,
 		    arma::vec weight,
 		    arma::vec method,
 		    std::vector< int > op,
@@ -722,7 +725,7 @@ Rcpp::List GPC2_cpp(arma::mat endpoint,
 					       endpoint(indexStrataT[iter_T], index_endpoint[iter_d]),
 					       status(indexStrataC[iter_C], index_status[iter_d]),
 					       status(indexStrataT[iter_T], index_status[iter_d]),
-					       threshold[iter_d],
+					       threshold[iter_d], restriction[iter_d],
 					       list_survTimeC[iter_d][iter_strata].row(iter_C), list_survTimeT[iter_d][iter_strata].row(iter_T),
 					       list_survJumpC[iter_d][iter_strata], list_survJumpT[iter_d][iter_strata],
 					       list_lastSurv[iter_d](iter_strata,0), list_lastSurv[iter_d](iter_strata,1),
